==> minitube-src-0.1.tar.gz: minitube/src/AboutView.cpp <==
#include "AboutView.h"
#include "Constants.h"

AboutView::AboutView(QWidget *parent) : QWidget(parent) {

    QBoxLayout *aboutlayout = new QHBoxLayout(this);
    aboutlayout->setAlignment(Qt::AlignCenter);
    aboutlayout->setSpacing(30);

    QLabel *logo = new QLabel(this);
    logo->setPixmap(QPixmap(":/images/app.png"));
    aboutlayout->addWidget(logo, 0, Qt::AlignTop);

    QBoxLayout *layout = new QVBoxLayout();
    layout->setAlignment(Qt::AlignCenter);
    layout->setSpacing(30);
    aboutlayout->addLayout(layout);

    QString s = "<h1>" + QString(Constants::APP_NAME) + "</h1>"
                "<p>There's life outside the browser!</p>"
                "<p>" + tr("Version").append(" ").append(Constants::VERSION) + "</p>"
                "<p>This is a \"Technology Preview\" release, do not expect it to be perfect.</p>"
                + QString("<p><a href=\"%1/\">%1</a></p>").arg(Constants::WEBSITE) +
                "<p>Please report bugs and send in your ideas to <a href=\"mailto:flavio.tordini@gmail.com\">flavio.tordini@gmail.com</a></p>"
                "<p>Released under the <a href=\"http://www.gnu.org/licenses/gpl.html\">GNU General Public License</a></p>"
                "<p>Icon designed by needcoffee (Sebastian).</p>"
                "<p>&copy; 2009 Flavio Tordini</p>";
    QLabel *infoLabel = new QLabel(s, this);
    infoLabel->setOpenExternalLinks(true);
    layout->addWidget(infoLabel);

    QLayout *buttonLayout = new QHBoxLayout();
    buttonLayout->setAlignment(Qt::AlignLeft);
    QPushButton *closeButton = new QPushButton("&Close", this);
    closeButton->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);

    closeButton->setDefault(true);
    closeButton->setFocus(Qt::OtherFocusReason);
    connect(closeButton, SIGNAL(clicked()), parent, SLOT(goBack()));
    buttonLayout->addWidget(closeButton);

    layout->addLayout(buttonLayout);

}

==> minitube-src-0.2.1.tar.gz: minitube/src/AboutView.cpp <==
#include "AboutView.h"
#include "Constants.h"

AboutView::AboutView(QWidget *parent) : QWidget(parent) {

    QBoxLayout *aboutlayout = new QHBoxLayout(this);
    aboutlayout->setAlignment(Qt::AlignCenter);
    aboutlayout->setSpacing(30);

    QLabel *logo = new QLabel(this);
    logo->setPixmap(QPixmap(":/images/app.png"));
    aboutlayout->addWidget(logo, 0, Qt::AlignTop);

    QBoxLayout *layout = new QVBoxLayout();
    layout->setAlignment(Qt::AlignCenter);
    layout->setSpacing(30);
    aboutlayout->addLayout(layout);

    QString s = "<h1>" + QString(Constants::APP_NAME) + "</h1>"
                "<p>There's life outside the browser!</p>"
                "<p>" + tr("Version").append(" ").append(Constants::VERSION) + "</p>"
                + QString("<p><a href=\"%1/\">%1</a></p>").arg(Constants::WEBSITE) +

                "<p>This is a \"Technology Preview\" release, do not expect it to be perfect.<br/>"
                "Report bugs and send in your ideas to <a href=\"mailto:flavio.tordini@gmail.com\">flavio.tordini@gmail.com</a></p>"

                "<p>" + Constants::APP_NAME +  " is Free Software but its development takes precious time.<br/>"
                "Please <a href=\"" + QString(Constants::WEBSITE).append("#donate") + "\">donate via PayPal</a>"
                " to support the continued development of " + Constants::APP_NAME + ".</p>"

                "<p>Icon designed by needcoffee (Sebastian).</p>"
                "<p>Released under the <a href=\"http://www.gnu.org/licenses/gpl.html\">GNU General Public License</a></p>"
                "<p>&copy; 2009 " + Constants::ORG_NAME + "</p>";
    QLabel *infoLabel = new QLabel(s, this);
    infoLabel->setOpenExternalLinks(true);
    layout->addWidget(infoLabel);

    QLayout *buttonLayout = new QHBoxLayout();
    buttonLayout->setAlignment(Qt::AlignLeft);
    QPushButton *closeButton = new QPushButton("&Close", this);
    closeButton->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);

    closeButton->setDefault(true);
    closeButton->setFocus(Qt::OtherFocusReason);
    connect(closeButton, SIGNAL(clicked()), parent, SLOT(goBack()));
    buttonLayout->addWidget(closeButton);

    layout->addLayout(buttonLayout);

}
